@@ -15,14 +15,15 @@ except ImportError:
 
 
 class TestZip(unittest.TestCase):
+    root = 'importlib_metadata.tests.data'
+
     def setUp(self):
         # Find the path to the example-*.whl so we can add it to the front of
         # sys.path, where we'll then try to find the metadata thereof.
         self.resources = ExitStack()
         self.addCleanup(self.resources.close)
         wheel = self.resources.enter_context(
-            path('importlib_metadata.tests.data',
-                 'example-21.12-py3-none-any.whl'))
+            path(self.root, 'example-21.12-py3-none-any.whl'))
         sys.path.insert(0, str(wheel))
         self.resources.callback(sys.path.pop, 0)
 
@@ -33,6 +34,8 @@ class TestZip(unittest.TestCase):
         scripts = dict(entry_points()['console_scripts'])
         entry_point = scripts['example']
         self.assertEqual(entry_point.value, 'example:main')
+        entry_point = scripts['Example']
+        self.assertEqual(entry_point.value, 'example:main')
 
     def test_missing_metadata(self):
         self.assertIsNone(distribution('example').read_text('does not exist'))
@@ -53,8 +56,7 @@ class TestEgg(TestZip):
         self.resources = ExitStack()
         self.addCleanup(self.resources.close)
         egg = self.resources.enter_context(
-            path('importlib_metadata.tests.data',
-                 'example-21.12-py3.6.egg'))
+            path(self.root, 'example-21.12-py3.6.egg'))
         sys.path.insert(0, str(egg))
         self.resources.callback(sys.path.pop, 0)
 
